/**
* Title: TemplateSkeleton
* Description:
* Copyright:    Copyright (c) 2009-2010
* Company:      Morpheus
* @author Stefano Adriani
* @version 1.0
*/

package adriani.jws.template.eclipse;

import adriani.jws.template.service.* ;
import adriani.jws.template.messages.* ;

/**
* This class should have the same structure of the java skeleton produced by the Web Tools Platform plugin
* of the Eclipse IDE. When it's necessary to update the classes in this package, in order to reflect a
* change in the WSDL document, this is the only class that MUST NOT BE OVERWRITTEN!<br/> 
* This because the skeleton produced by the WTP plugin is always empty, hence it's convenient to keep
* the implementation code of this class and eventually merge it with the new skeleton.<br/>
* Moreover, since the <code>ServiceLogic</code> class uses the wrappers offered by the <code>messages</code> 
* package, this class should be responsible for convertion of the Eclipse <code>ADBBean</code> java classes 
* into the proper message classes, and viceversa.<br/><br/>
*
* This class should be invoked by calling an URL of the type:<br/><br/>
*
* <code>http://localhost:8080/axis2/services/template/getInformation</code>
*/
public class TemplateSkeleton {

  	/** A reference to the service businesse logic class.													*/
	protected ServiceLogic logic ;

  	/** Beginning of each logging message produced by this class.											*/
	protected String leadingName = "TemplateSkeleton - " ;
       
	/**
	* Notice that the <code>User</code> input java object is created by the 
	* <code>TemplateMessageReceiverInOut</code> class when invoking the <code>User.Factory.parse()</code> 
	* STATIC method (no one instanciate a <code>User</code> object within the skeleton class).
	* 
	* @param user the object wrapping the customer data (produced by the WTP Eclipse plug-in)
	* @return an <code>Information</code> object, as produced by the WTP Eclipse plug-in
	*/
	public Information getInformation(User user) {
	
		logic = new ServiceLogic() ;									// Creating the business logic manager
		WrapperIn input = new WrapperIn(user) ;							// WRAPPING the SOAP IN parameter
		WrapperOut output = logic.getOutput(input) ;					// ACTUAL CALL
		Information information = (Information) output.getElement() ;	// CREATING the SOAP OUT parameter
		return information ;
	}
	
// **********************************			ACCESSORS			*****************************************	
	
	/**
	* Accessor method, used only during development by the <code>SimpleClient</code> class.
	*
	* @return the current instance of the <code>ServiceLogic</code> class
	*/
	public ServiceLogic getServiceLogic() 			{		return logic ;									}
     
} // End of class
    