/**
* Title: WrapperData
* Description:
* Copyright:    Copyright (c) 2009-2010
* Company:      Morpheus Quality Technologies
* @author Stefano Adriani
* @version 1.0
*/

package adriani.jws.template.messages ;

import adriani.jws.template.* ;
import adriani.jws.template.service.* ;
import adriani.jws.template.eclipse.* ;

/**
* WrapperData - general class wrapping the inner <code>ADBBean</code> elements containing a single
* <code>SingleRecordType</code> object.
*/
public class WrapperData extends Wrapper {

 	/** Static default value for the FIRST field (should match one of the static reference values).			*/
	public static final StringBuffer 		FIRST			= new StringBuffer("FIRST") ;
	/** Static default value for the FIRST field (should match one of the static reference values).			*/
	public static final StringBuffer 		SECOND			= new StringBuffer("SECOND") ;

  	/** Wrapped output value, used to fill the SOAP response during validation.								*/
	protected 			StringBuffer	 	first ;
	/** Wrapped output value, used to fill the SOAP response during validation.								*/
	protected 			StringBuffer	 	second ;

	/**
	* Stateless constructor, loading the default values into this wrapper.
	*
	* @see setDefaults()
	*/
	public WrapperData() {

		this.leadingName = "WrapperData - " ;		// MUST BE first line
		this.setDefaults() ;
	}

// **********************************************************************************************************
// **********************************		ADBBEAN MANAGEMENT		*****************************************
// **********************************************************************************************************

	/**
	* Validation is performed by the Eclipse's <code>ADBBean</code> objects ( e.g. NameType.setNameType() ).
	* If the validation process is succesfull, the resulting <code>ADBBean</code> object is stored as
	* class field to save computation time, since after validation we expect that the method
	* <code>getElement()</code> should be invoked.<br/><br/>
	*
	* <strong>Remark:</strong> to grant LOOSE COUPLING to the WSDL, the <code>ADBBean</code> Java classes
	* should be used only within this method and in the <code>forceMessage()</code> method, not elsewhere.
	*
	* @return a reference to the <code>ADBBean</code> object wrapped by this class
	*/
	public Object validate() throws WrapperFault {

		// 1. Defining root element
		String msg = null ;
		RecordsType root = new RecordsType() ;

		// 2. Defining ADBBean types
		NameType							firstType					= new NameType() ;
		NameType							secondType					= new NameType() ;

		// 3. Trying to set the class attribute into the corresponding ADBBean elements
		String value = this.first.toString() ;
		for (int i = 0 ; i < 2 ; i++) {
			try 				{	firstType.setNameType(value) ; 				break ;						}
			catch(Exception e)	{ 	value = FIRST.toString() ;					msg = "FIRST" ;				}
		}
		value = this.second.toString() ;
		for (int i = 0 ; i < 2 ; i++) {
			try 				{	secondType.setNameType(value) ; 			break ;						}
			catch(Exception e)	{ 	value = SECOND.toString() ;					msg = "SECOND" ;			}
		}

		// 4. Setting the root main element, which can not throw exceptions
		root.setFirst( firstType ) ;
		root.setSecond( secondType ) ;

		// 5. Storing root element as class field
		this.element = (Object) root ;

		// 6. Eventually handling errors
		if (msg == null) {
			if (Settings.DETAILS) System.out.println(leadingName + "Wrapped a valid single record") ;
		} else {
			if (Settings.DETAILS) System.out.println(leadingName + "Invalid single wrapper, using defaults") ;
			throw new WrapperFault(msg) ;
		}

		// 7. returning valid root element
		return this.element ;
	}

	/**
	* Load all the STATIC default values (defined in this class) into the corresponding class attributes.
	* This method is called by the constructor to ensure that we "empty wrapper" contains always some
	* good default values matching the WSDL constrains.
	*
	* @see WrapperData()
	*/
	public void setDefaults() {

		setFirst(FIRST) ;
		setSecond(SECOND) ;
		if (Settings.DETAILS) System.out.println(leadingName + "Set defaults values") ;
	}

// **********************************************************************************************************
// **********************************			ACCESSORS		*********************************************
// **********************************************************************************************************

	/**
	* Accessor method.
	*/
	public StringBuffer getFirst()					{		return this.first ;								}

	/**
	* Accessor method.
	*/
	public StringBuffer getSecond()					{		return this.second ;							}

// **********************************************************************************************************
// **********************************			MUTATORS		*********************************************
// **********************************************************************************************************

	/**
	* Mutator method.
	*/
	public void setFirst(StringBuffer value)		{		this.first = value ;							}

	/**
	* Mutator method.
	*/
	public void setSecond(StringBuffer value)		{		this.second = value ;							}

	/**
	* Mutator method (template for integer fields).
	*
	public void setThird(int value) {

		try 				{ this.third = Integer.parseInt( value.toString() ) ;							}
		catch(Exception e) 	{ this.third = NOT_AVAILABLE ;													}
		//System.out.println(leadingName + "Set third value: " + this.third) ;
	}*/

} // END OF CLASS