/**
* Title: RotateThread
* Description:
* Copyright:    Copyright (c) 2007-2010
* Company:      Morpheus Quality Technologies
* @author Stefano Adriani
* @version 1.0
*/

package adriani.jws.template.util ;

import adriani.jws.template.* ;

import java.util.* ;
import java.util.logging.* ;

 /**
 * This is the thread managing the rotation of the current <code>Logger</code> file object.
 */
 public class RotateThread extends GeneralThread implements Runnable {

	/** The sleep time for this thread (milliseconds).														*/
	protected 						long 			sleepTime ;

	/** A reference to the <code>LoggerManager</code> needing rotation.										*/
	protected 						LoggerManager 	manager ;

  	/** Beginning of each logging message produced by this class.	 										*/
	protected 						String 			leadingName 	= "Rotate Thread - " ;

	/**
	* Standard constructor.
	*
	* @param manager the <code>LoggerManager</code> class creating and starting this thread
	* @param time the sleeping time (in minutes) this thread must sleep before performing log rotation
	*/
	public RotateThread(LoggerManager manager, int time) {

		// Setting parent class fields
		this.active = true ;
		this.running = true ;

		// Setting class fields
		this.manager = manager ;
		if (time == 0) time = Settings.ROTATE ;
		this.sleepTime = time*1000*60 ;
	}

	/**
	* This method contains an endless while cycle, performed as long as the class attribute
	* <code>running</code> is set to <code>true</code>.<br/><br/>
	*
	* <strong>Remark:</strong> this class do not consider the option that we are using the Log4j mechanism,
	* since this thread should be created only when we use the <code>SystemLogger</code> class.
	*
	* @see GeneralThread#stopCycle()
	* @see GeneralThread#isRunning()
	*/
	public void run() {

		int minutes = (int) (sleepTime/60000) ;
		Logger logger = java.util.logging.Logger.getLogger(Settings.LOGGER) ;
		logger.info(leadingName + "Started with timeout: " + minutes + " minutes") ;

		while (this.running) {

			// 1. Sleeping for the set time
			try 							{ theThread.sleep(sleepTime) ; 										}
			catch (InterruptedException e)	{ System.err.println(leadingName + "Interrupted while sleeping") ;	}

			// 2. Trying to log the rotate operation
			try {
				logger = java.util.logging.Logger.getLogger(Settings.LOGGER) ;
				logger.info(leadingName + "Changing the log file") ;
				Handler[] handlers = logger.getHandlers() ;
				if ( (handlers.length > 0) && (handlers[0] != null) ) handlers[0].flush() ;
			} catch (Exception e) {
				System.err.println(leadingName + "Logger not found") ;
			}

			// 3. Performing log file rotation
			if (active) {
				manager.rotate() ;
			} else {
				logger = java.util.logging.Logger.getLogger(Settings.LOGGER) ;
				if (logger != null) logger.warning(leadingName + "Not active: skipped logger rotation") ;
			}

		} // End of while
	}

// **********************************************************************************************************
// **********************************			ACCESSORS		*********************************************
// **********************************************************************************************************

	/**
	* Accessor method.
	*/
	public long getSleepTime() 				{		return sleepTime ;										}

}	// END OF CLASS