/**
* Title: ThreadManager
* Description:
* Copyright:    Copyright (c) 2003-2010
* Company:      Morpheus Quality Technologies
* @author Stefano Adriani
* @version 1.0
*/

package adriani.jws.template.util ;

import adriani.jws.template.* ;

/**
* A very simple class used only during development or debug to monitor the status of all the threads
* used by this project.
*/
public class ThreadManager {

  	/** Beginning of each logging message printed on the STDOUT	.											*/
	protected 				String 		leadingName 	= "ThreadManager - " ;

	/** Retrieving the logger instance to be used for this class (static).									*/
	protected static 		WSLogger	logger 			= WSLogger.getLogger(ThreadManager.class) ;

 	/** 
	* Print on the STDOUT the list of all active threads in the current <code>ThreadGroup</code>.
	*/
    public static void printList() {	
	
		StringBuffer message = getFormattedList() ;
		System.out.println(message.toString()) ;
	}
	
 	/** 
	* Print in the LOG file the list of all active threads in the current <code>ThreadGroup</code>.
	*/
    public static void logList() {	

		StringBuffer message = getFormattedList() ;
		logger.logInfo(message.toString()) ;
	}
	
	/** 
	* Returns the array of active threads in the current <code>ThreadGroup</code>.
	*
	* @return a <code>StringBuffer</code> object describing the printable thread list
	*/
    public static StringBuffer getFormattedList() {
	
		Thread[] list = getList() ;
		//Thread.currentThread().setName("Template web service") ;
		
		StringBuffer message = new StringBuffer("\nTHREAD LIST:\n") ;
		for (int i = 0 ;  i < list.length; i++) if (list[i] != null) {
			message.append(list[i].getName() + " [" + list[i].getId() +"] - ") ;
			message.append("Priority: " + list[i].getPriority() + " (" + list[i].getState() + ")\n") ;
		}
		return message ;
	}	

	/** 
	* Returns the array of active threads in the current <code>ThreadGroup</code>.
	*
	* @return the array of all the active threads
	*/
    public static Thread[] getList() {

		ThreadGroup group = Thread.currentThread().getThreadGroup() ;
		Thread[] list = new Thread[group.activeCount()] ;
		if (group != null) group.enumerate(list) ;
		return list ;
	}
	
} // END OF CLASS